==> charlatan_0.2.2.tar.gz: charlatan/R/jobs-provider-uk_UA.R <==
# modified from the python library faker:
# https://github.com/joke2k/faker/blob/master/faker/providers/job/uk_UA/__init__.py

job_formats_uk_ua <- c(
  "\u0410\u0433\u0440\u043e\u043d\u043e\u043c",
  "\u0410\u0434\u0432\u043e\u043a\u0430\u0442",
  "\u0410\u043a\u0442\u043e\u0440",
  "\u0410\u043a\u0443\u0448\u0435\u0440",
  "\u0410\u043d\u0442\u0440\u043e\u043f\u043e\u043b\u043e\u0433",
  "\u0410\u0440\u0445\u0456\u0442\u0435\u043a\u0442\u043e\u0440",
  "\u0410\u0440\u0445\u0435\u043e\u043b\u043e\u0433",
  "\u0410\u0441\u0442\u0440\u043e\u043d\u0430\u0432\u0442",
  "\u0410\u0441\u0442\u0440\u043e\u043d\u043e\u043c",
  "\u0410\u0441\u0442\u0440\u043e\u0444\u0456\u0437\u0438\u043a",
  "\u0411\u0456\u0431\u043b\u0456\u043e\u0433\u0440\u0430\u0444",
  "\u0411\u0456\u043e\u043b\u043e\u0433",
  "\u0411\u0456\u0437\u043d\u0435\u0441\u043c\u0435\u043d",
  "\u0411\u043e\u0442\u0430\u043d\u0456\u043a",
  "\u0411\u0443\u0434\u043d\u0438\u043a",
  "\u0411\u0443\u0445\u0433\u0430\u043b\u0442\u0435\u0440",
  "\u0411\u0456\u0431\u043b\u0456\u043e\u0442\u0435\u043a\u0430\u0440",
  "\u0412\u0435\u0442\u0435\u0440\u0438\u043d\u0430\u0440",
  "\u0412\u0438\u043f\u0440\u043e\u0431\u0443\u0432\u0430\u0447",
  "\u0412\u043e\u0434\u0456\u0439",
  "\u0412\u0447\u0438\u0442\u0435\u043b\u044c",
  "\u0412\u0456\u0437\u0430\u0436\u0438\u0441\u0442",
  "\u0413\u0435\u043e\u0433\u0440\u0430\u0444",
  "\u0413\u0435\u043e\u043b\u043e\u0433",
  "\u0413\u0435\u043e\u0444\u0456\u0437\u0438\u043a",
  "\u0413\u0438\u0446\u0435\u043b\u044c",
  "\u0413\u0456\u043d\u0435\u043a\u043e\u043b\u043e\u0433",
  "\u0413\u0456\u0440\u043d\u0438\u043a",
  "\u0413\u0456\u0440\u043d\u0438\u0447\u0438\u0439 \u0456\u043d\u0436\u0435\u043d\u0435\u0440",
  "\u0413\u043e\u043b\u043e\u0432\u043d\u0438\u0439 \u043c\u0435\u0440\u043a\u0448\u0435\u0439\u0434\u0435\u0440",
  "\u0413\u0440\u0430\u0444\u0456\u043a",
  "\u0413\u0440\u043e\u043c\u0430\u0434\u0441\u044c\u043a\u0438\u0439 \u0434\u0456\u044f\u0447",
  "\u0490\u0440\u0443\u043d\u0442\u043e\u0437\u043d\u0430\u0432\u0435\u0446\u044c",
  "\u0414\u0435\u0440\u0436\u0430\u0432\u043d\u0438\u0439 \u0441\u043b\u0443\u0436\u0431\u043e\u0432\u0435\u0446\u044c",
  "\u0414\u0435\u0440\u0443\u043d",
  "\u0414\u0435\u0442\u0435\u043a\u0442\u0438\u0432",
  "\u0414\u0438\u0437\u0430\u0439\u043d\u0435\u0440",
  "\u0414\u0438\u043f\u043b\u043e\u043c\u0430\u0442",
  "\u0414\u0438\u0440\u0438\u0433\u0435\u043d\u0442",
  "\u0414\u043e\u0446\u0435\u043d\u0442",
  "\u0414\u0440\u0430\u043c\u0430\u0442\u0443\u0440\u0433",
  "\u0414\u0456-\u0434\u0436\u0435\u0439",
  "\u0414\u0430\u043d\u0442\u0438\u0441\u0442",
  "\u0415\u043a\u043e\u043d\u043e\u043c\u0456\u0441\u0442",
  "\u0415\u043b\u0435\u043a\u0442\u0440\u0438\u043a",
  "\u0415\u043b\u0435\u043a\u0442\u0440\u043e\u043c\u043e\u043d\u0442\u0435\u0440",
  "\u0415\u043b\u0435\u043a\u0442\u0440\u043e\u043c\u043e\u043d\u0442\u0430\u0436\u043d\u0438\u043a",
  "\u0415\u043b\u0435\u043a\u0442\u0440\u043e\u0441\u043b\u044e\u0441\u0430\u0440",
  "\u0415\u043b\u0435\u043a\u0442\u0440\u043e\u0442\u0435\u0445\u043d\u0456\u043a",
  "\u0415\u043f\u0456\u0434\u0435\u043c\u0456\u043e\u043b\u043e\u0433",
  "\u0415\u0442\u043d\u043e\u0433\u0440\u0430\u0444",
  "\u0404\u0432\u043d\u0443\u0445",
  "\u0404\u0433\u0435\u0440",
  "\u0416\u0443\u0440\u043d\u0430\u043b\u0456\u0441\u0442",
  "\u0416\u0438\u0432\u043e\u043f\u0438\u0441\u0435\u0446\u044c",
  "\u0417\u043e\u043b\u043e\u0442\u0430\u0440",
  "\u0417\u043e\u043e\u043b\u043e\u0433",
  "\u0406\u043d\u0436\u0435\u043d\u0435\u0440",
  "\u0406\u0441\u0442\u043e\u0440\u0438\u043a",
  "\u041a\u0430\u0441\u043a\u0430\u0434\u0435\u0440",
  "\u041a\u0456\u043d\u043e\u0440\u0435\u0436\u0438\u0441\u0435\u0440",
  "\u041a\u043b\u0430\u0432\u0456\u0448\u043d\u0438\u043a",
  "\u041a\u043b\u043e\u0443\u043d",
  "\u041a\u043e\u043c\u043f\u043e\u0437\u0438\u0442\u043e\u0440",
  "\u041a\u043e\u043d\u0441\u0442\u0440\u0443\u043a\u0442\u043e\u0440",
  "\u041a\u0440\u0430\u0454\u0437\u043d\u0430\u0432\u0435\u0446\u044c",
  "\u041a\u0443\u0448\u043d\u0456\u0440",
  "\u041a\u0456\u043d\u043e\u0430\u043a\u0442\u043e\u0440",
  "\u041a\u0456\u043d\u043e\u043a\u0440\u0438\u0442\u0438\u043a",
  "\u041a\u0456\u043d\u043e\u0440\u0435\u0436\u0438\u0441\u0435\u0440",
  "\u041a\u0443\u0440\'\u0454\u0440",
  "\u041a\u0443\u0445\u0430\u0440",
  "\u041a\u0456\u043d\u043e\u043b\u043e\u0433",
  "\u041a\u0440\u0443\u043f\'\u0454",
  "\u041b\u044c\u043e\u0442\u0447\u0438\u043a",
  "\u041b\u0456\u043a\u0430\u0440",
  "\u041b\u0456\u0442\u0435\u0440\u0430\u0442\u0443\u0440\u043e\u0437\u043d\u0430\u0432\u0435\u0446\u044c",
  "\u041b\u043e\u043a\u0441\u043c\u0430\u0439\u0441\u0442\u0435\u0440",
  "\u041c\u0430\u0442\u0435\u043c\u0430\u0442\u0438\u043a",
  "\u041c\u0430\u0448\u0438\u043d\u0456\u0441\u0442",
  "\u041c\u0435\u0434\u0438\u043a",
  "\u041c\u0435\u043d\u0435\u0434\u0436\u0435\u0440",
  "\u041c\u0438\u0441\u0442\u0435\u0446\u0442\u0432\u043e\u0437\u043d\u0430\u0432\u0435\u0446\u044c",
  "\u041c\u0456\u0440\u043e\u0448\u043d\u0438\u043a",
  "\u041c\u0456\u043a\u0440\u043e\u0431\u0456\u043e\u043b\u043e\u0433",
  "\u041c\u0456\u043d\u0435\u0440\u0430\u043b\u043e\u0433",
  "\u041c\u043e\u0432\u043e\u0437\u043d\u0430\u0432\u0435\u0446\u044c",
  "\u041c\u043e\u0434\u0435\u043b\u044c",
  "\u041c\u043e\u0434\u0435\u043b\u044c\u0454\u0440",
  "\u041c\u0443\u0437\u0438\u043a\u0430\u043d\u0442",
  "\u041c\u0443\u0437\u0438\u043a\u043e\u0437\u043d\u0430\u0432\u0435\u0446\u044c",
  "\u041c\u0443\u0437\u0438\u0447\u043d\u0438\u0439 \u0440\u0435\u0434\u0430\u043a\u0442\u043e\u0440",
  "\u041c\u0430\u0440\u043a\u0435\u0442\u043e\u043b\u043e\u0433",
  "\u041c\'\u044f\u0441\u043d\u0438\u043a",
  "\u041d\u0430\u043c\u043e\u0442\u0443\u0432\u0430\u043b\u044c\u043d\u0438\u043a",
  "\u041d\u0430\u0443\u043a\u043e\u0432\u0435\u0446\u044c",
  "\u041d\u044f\u043d\u044f",
  "\u041d\u043e\u0442\u0430\u0440\u0456\u0443\u0441",
  "\u041f\u0430\u043b\u0435\u043e\u043d\u0442\u043e\u043b\u043e\u0433",
  "\u041f\u0430\u0440\u0430\u043b\u0435\u0433\u0430\u043b",
  "\u041f\u0430\u0440\u0444\u044e\u043c\u0435\u0440",
  "\u041f\u0430\u0442\u043e\u043b\u043e\u0433\u043e\u0430\u043d\u0430\u0442\u043e\u043c",
  "\u041f\u0435\u0434\u0430\u0433\u043e\u0433",
  "\u041f\u0435\u043a\u0430\u0440",
  "\u041f\u0435\u0440\u0435\u043a\u043b\u0430\u0434\u0430\u0447",
  "\u041f\u0435\u0442\u0440\u043e\u0433\u0440\u0430\u0444",
  "\u041f\u0438\u0441\u044c\u043c\u0435\u043d\u043d\u0438\u043a",
  "\u041f\u0456\u0430\u043d\u0456\u0441\u0442",
  "\u041f\u0456\u0434\u043f\u0440\u0438\u0454\u043c\u0435\u0446\u044c",
  "\u041f\u0456\u043b\u043e\u0442",
  "\u041f\u0440\u0430\u0432\u043d\u0438\u043a",
  "\u041f\u0440\u043e\u0433\u0440\u0430\u043c\u0456\u0441\u0442",
  "\u041f\u0440\u043e\u0432\u0456\u0437\u043e\u0440",
  "\u041f\u0440\u043e\u043a\u0443\u0440\u043e\u0440",
  "\u041f\u0440\u043e\u043c\u0438\u0441\u043b\u043e\u0432\u0435\u0446\u044c",
  "\u041f\u0440\u043e\u0444\u0435\u0441\u043e\u0440",
  "\u041f\u0441\u0438\u0445\u043e\u043b\u043e\u0433",
  "\u041f\u0443\u0431\u043b\u0456\u0446\u0438\u0441\u0442",
  "\u041f\u0440\u043e\u0434\u044e\u0441\u0435\u0440",
  "\u041f\u0430\u0431\u043b\u0456\u043a \u0440\u0438\u043b\u0435\u0439\u0448\u043d\u0437",
  "\u0420\u0435\u0436\u0438\u0441\u0435\u0440",
  "\u0420\u0456\u0437\u043d\u043e\u0440\u043e\u0431\u043e\u0447\u0438\u0439",
  "\u0420\u0435\u0430\u0431\u0456\u043b\u0456\u0442\u043e\u043b\u043e\u0433",
  "\u0420\u0435\u0434\u0430\u043a\u0442\u043e\u0440",
  "\u0420\u0435\u0441\u0442\u0430\u0432\u0440\u0430\u0442\u043e\u0440",
  "\u0420\u0456\u0435\u043b\u0442\u043e\u0440",
  "\u0421\u0430\u043d\u0442\u0435\u0445\u043d\u0456\u043a",
  "\u0421\u043a\u043b\u0430\u0434\u0430\u043b\u044c\u043d\u0438\u043a",
  "\u0421\u043a\u0443\u043b\u044c\u043f\u0442\u043e\u0440",
  "\u0421\u043e\u0446\u0456\u043e\u043b\u043e\u0433",
  "\u0421\u043f\u0456\u0432\u0430\u043a",
  "\u0421\u0446\u0435\u043d\u0430\u0440\u0438\u0441\u0442",
  "\u0421\u0442\u0440\u043e\u043f\u0430\u043b\u044c\u043d\u0438\u043a",
  "\u0421\u0442\u043e\u043c\u0430\u0442\u043e\u043b\u043e\u0433",
  "\u0421\u043b\u0456\u0434\u0447\u0438\u0439",
  "\u0421\u0442\u0438\u043b\u0456\u0441\u0442",
  "\u0421\u0435\u043a\u0440\u0435\u0442\u0430\u0440",
  "\u0424\u0430\u0440\u043c\u0430\u0446\u0435\u0432\u0442",
  "\u0424\u0435\u0440\u043c\u0435\u0440",
  "\u0424\u0456\u0437\u0438\u043a",
  "\u0424\u0456\u043b\u043e\u043b\u043e\u0433",
  "\u0424\u043e\u043b\u044c\u043a\u043b\u043e\u0440\u0438\u0441\u0442",
  "\u0424\u043e\u0442\u043e\u0433\u0440\u0430\u0444",
  "\u0424\u0440\u0456\u043b\u0430\u043d\u0441\u0435\u0440",
  "\u0424\u0443\u0442\u0431\u043e\u043b\u0456\u0441\u0442",
  "\u0424\u043b\u043e\u0440\u0438\u0441\u0442",
  "\u0425\u0456\u043c\u0456\u043a",
  "\u0425\u0443\u0434\u043e\u0436\u043d\u0438\u043a",
  "\u0425\u043e\u0440\u0435\u043e\u0433\u0440\u0430\u0444",
  "\u0428\u0435\u0440\u0438\u0444",
  "\u0428\u0432\u0430\u0447\u043a\u0430",
  "\u0428\u0442\u0443\u043a\u0430\u0442\u0443\u0440",
  "\u042e\u0432\u0435\u043b\u0456\u0440",
  "\u042e\u0440\u0438\u0441\u0442"
)

==> charlatan_0.6.1.tar.gz: charlatan/R/jobs-provider-uk_UA.R <==
# modified from the python library faker:
# https://github.com/joke2k/faker/blob/master/faker/providers/job/uk_UA/__init__.py

job_formats_uk_ua <- c(
  "\u0410\u0433\u0440\u043e\u043d\u043e\u043c",
  "\u0410\u0434\u0432\u043e\u043a\u0430\u0442",
  "\u0410\u043a\u0442\u043e\u0440",
  "\u0410\u043a\u0443\u0448\u0435\u0440",
  "\u0410\u043d\u0442\u0440\u043e\u043f\u043e\u043b\u043e\u0433",
  "\u0410\u0440\u0445\u0456\u0442\u0435\u043a\u0442\u043e\u0440",
  "\u0410\u0440\u0445\u0435\u043e\u043b\u043e\u0433",
  "\u0410\u0441\u0442\u0440\u043e\u043d\u0430\u0432\u0442",
  "\u0410\u0441\u0442\u0440\u043e\u043d\u043e\u043c",
  "\u0410\u0441\u0442\u0440\u043e\u0444\u0456\u0437\u0438\u043a",
  "\u0411\u0456\u0431\u043b\u0456\u043e\u0433\u0440\u0430\u0444",
  "\u0411\u0456\u043e\u043b\u043e\u0433",
  "\u0411\u0456\u0437\u043d\u0435\u0441\u043c\u0435\u043d",
  "\u0411\u043e\u0442\u0430\u043d\u0456\u043a",
  "\u0411\u0443\u0434\u043d\u0438\u043a",
  "\u0411\u0443\u0445\u0433\u0430\u043b\u0442\u0435\u0440",
  "\u0411\u0456\u0431\u043b\u0456\u043e\u0442\u0435\u043a\u0430\u0440",
  "\u0412\u0435\u0442\u0435\u0440\u0438\u043d\u0430\u0440",
  "\u0412\u0438\u043f\u0440\u043e\u0431\u0443\u0432\u0430\u0447",
  "\u0412\u043e\u0434\u0456\u0439",
  "\u0412\u0447\u0438\u0442\u0435\u043b\u044c",
  "\u0412\u0456\u0437\u0430\u0436\u0438\u0441\u0442",
  "\u0413\u0435\u043e\u0433\u0440\u0430\u0444",
  "\u0413\u0435\u043e\u043b\u043e\u0433",
  "\u0413\u0435\u043e\u0444\u0456\u0437\u0438\u043a",
  "\u0413\u0438\u0446\u0435\u043b\u044c",
  "\u0413\u0456\u043d\u0435\u043a\u043e\u043b\u043e\u0433",
  "\u0413\u0456\u0440\u043d\u0438\u043a",
  "\u0413\u0456\u0440\u043d\u0438\u0447\u0438\u0439 \u0456\u043d\u0436\u0435\u043d\u0435\u0440",
  "\u0413\u043e\u043b\u043e\u0432\u043d\u0438\u0439 \u043c\u0435\u0440\u043a\u0448\u0435\u0439\u0434\u0435\u0440",
  "\u0413\u0440\u0430\u0444\u0456\u043a",
  "\u0413\u0440\u043e\u043c\u0430\u0434\u0441\u044c\u043a\u0438\u0439 \u0434\u0456\u044f\u0447",
  "\u0490\u0440\u0443\u043d\u0442\u043e\u0437\u043d\u0430\u0432\u0435\u0446\u044c",
  "\u0414\u0435\u0440\u0436\u0430\u0432\u043d\u0438\u0439 \u0441\u043b\u0443\u0436\u0431\u043e\u0432\u0435\u0446\u044c",
  "\u0414\u0435\u0440\u0443\u043d",
  "\u0414\u0435\u0442\u0435\u043a\u0442\u0438\u0432",
  "\u0414\u0438\u0437\u0430\u0439\u043d\u0435\u0440",
  "\u0414\u0438\u043f\u043b\u043e\u043c\u0430\u0442",
  "\u0414\u0438\u0440\u0438\u0433\u0435\u043d\u0442",
  "\u0414\u043e\u0446\u0435\u043d\u0442",
  "\u0414\u0440\u0430\u043c\u0430\u0442\u0443\u0440\u0433",
  "\u0414\u0456-\u0434\u0436\u0435\u0439",
  "\u0414\u0430\u043d\u0442\u0438\u0441\u0442",
  "\u0415\u043a\u043e\u043d\u043e\u043c\u0456\u0441\u0442",
  "\u0415\u043b\u0435\u043a\u0442\u0440\u0438\u043a",
  "\u0415\u043b\u0435\u043a\u0442\u0440\u043e\u043c\u043e\u043d\u0442\u0435\u0440",
  "\u0415\u043b\u0435\u043a\u0442\u0440\u043e\u043c\u043e\u043d\u0442\u0430\u0436\u043d\u0438\u043a",
  "\u0415\u043b\u0435\u043a\u0442\u0440\u043e\u0441\u043b\u044e\u0441\u0430\u0440",
  "\u0415\u043b\u0435\u043a\u0442\u0440\u043e\u0442\u0435\u0445\u043d\u0456\u043a",
  "\u0415\u043f\u0456\u0434\u0435\u043c\u0456\u043e\u043b\u043e\u0433",
  "\u0415\u0442\u043d\u043e\u0433\u0440\u0430\u0444",
  "\u0404\u0432\u043d\u0443\u0445",
  "\u0404\u0433\u0435\u0440",
  "\u0416\u0443\u0440\u043d\u0430\u043b\u0456\u0441\u0442",
  "\u0416\u0438\u0432\u043e\u043f\u0438\u0441\u0435\u0446\u044c",
  "\u0417\u043e\u043b\u043e\u0442\u0430\u0440",
  "\u0417\u043e\u043e\u043b\u043e\u0433",
  "\u0406\u043d\u0436\u0435\u043d\u0435\u0440",
  "\u0406\u0441\u0442\u043e\u0440\u0438\u043a",
  "\u041a\u0430\u0441\u043a\u0430\u0434\u0435\u0440",
  "\u041a\u0456\u043d\u043e\u0440\u0435\u0436\u0438\u0441\u0435\u0440",
  "\u041a\u043b\u0430\u0432\u0456\u0448\u043d\u0438\u043a",
  "\u041a\u043b\u043e\u0443\u043d",
  "\u041a\u043e\u043c\u043f\u043e\u0437\u0438\u0442\u043e\u0440",
  "\u041a\u043e\u043d\u0441\u0442\u0440\u0443\u043a\u0442\u043e\u0440",
  "\u041a\u0440\u0430\u0454\u0437\u043d\u0430\u0432\u0435\u0446\u044c",
  "\u041a\u0443\u0448\u043d\u0456\u0440",
  "\u041a\u0456\u043d\u043e\u0430\u043a\u0442\u043e\u0440",
  "\u041a\u0456\u043d\u043e\u043a\u0440\u0438\u0442\u0438\u043a",
  "\u041a\u0456\u043d\u043e\u0440\u0435\u0436\u0438\u0441\u0435\u0440",
  "\u041a\u0443\u0440\'\u0454\u0440",
  "\u041a\u0443\u0445\u0430\u0440",
  "\u041a\u0456\u043d\u043e\u043b\u043e\u0433",
  "\u041a\u0440\u0443\u043f\'\u0454",
  "\u041b\u044c\u043e\u0442\u0447\u0438\u043a",
  "\u041b\u0456\u043a\u0430\u0440",
  "\u041b\u0456\u0442\u0435\u0440\u0430\u0442\u0443\u0440\u043e\u0437\u043d\u0430\u0432\u0435\u0446\u044c",
  "\u041b\u043e\u043a\u0441\u043c\u0430\u0439\u0441\u0442\u0435\u0440",
  "\u041c\u0430\u0442\u0435\u043c\u0430\u0442\u0438\u043a",
  "\u041c\u0430\u0448\u0438\u043d\u0456\u0441\u0442",
  "\u041c\u0435\u0434\u0438\u043a",
  "\u041c\u0435\u043d\u0435\u0434\u0436\u0435\u0440",
  "\u041c\u0438\u0441\u0442\u0435\u0446\u0442\u0432\u043e\u0437\u043d\u0430\u0432\u0435\u0446\u044c",
  "\u041c\u0456\u0440\u043e\u0448\u043d\u0438\u043a",
  "\u041c\u0456\u043a\u0440\u043e\u0431\u0456\u043e\u043b\u043e\u0433",
  "\u041c\u0456\u043d\u0435\u0440\u0430\u043b\u043e\u0433",
  "\u041c\u043e\u0432\u043e\u0437\u043d\u0430\u0432\u0435\u0446\u044c",
  "\u041c\u043e\u0434\u0435\u043b\u044c",
  "\u041c\u043e\u0434\u0435\u043b\u044c\u0454\u0440",
  "\u041c\u0443\u0437\u0438\u043a\u0430\u043d\u0442",
  "\u041c\u0443\u0437\u0438\u043a\u043e\u0437\u043d\u0430\u0432\u0435\u0446\u044c",
  "\u041c\u0443\u0437\u0438\u0447\u043d\u0438\u0439 \u0440\u0435\u0434\u0430\u043a\u0442\u043e\u0440",
  "\u041c\u0430\u0440\u043a\u0435\u0442\u043e\u043b\u043e\u0433",
  "\u041c\'\u044f\u0441\u043d\u0438\u043a",
  "\u041d\u0430\u043c\u043e\u0442\u0443\u0432\u0430\u043b\u044c\u043d\u0438\u043a",
  "\u041d\u0430\u0443\u043a\u043e\u0432\u0435\u0446\u044c",
  "\u041d\u044f\u043d\u044f",
  "\u041d\u043e\u0442\u0430\u0440\u0456\u0443\u0441",
  "\u041f\u0430\u043b\u0435\u043e\u043d\u0442\u043e\u043b\u043e\u0433",
  "\u041f\u0430\u0440\u0430\u043b\u0435\u0433\u0430\u043b",
  "\u041f\u0430\u0440\u0444\u044e\u043c\u0435\u0440",
  "\u041f\u0430\u0442\u043e\u043b\u043e\u0433\u043e\u0430\u043d\u0430\u0442\u043e\u043c",
  "\u041f\u0435\u0434\u0430\u0433\u043e\u0433",
  "\u041f\u0435\u043a\u0430\u0440",
  "\u041f\u0435\u0440\u0435\u043a\u043b\u0430\u0434\u0430\u0447",
  "\u041f\u0435\u0442\u0440\u043e\u0433\u0440\u0430\u0444",
  "\u041f\u0438\u0441\u044c\u043c\u0435\u043d\u043d\u0438\u043a",
  "\u041f\u0456\u0430\u043d\u0456\u0441\u0442",
  "\u041f\u0456\u0434\u043f\u0440\u0438\u0454\u043c\u0435\u0446\u044c",
  "\u041f\u0456\u043b\u043e\u0442",
  "\u041f\u0440\u0430\u0432\u043d\u0438\u043a",
  "\u041f\u0440\u043e\u0433\u0440\u0430\u043c\u0456\u0441\u0442",
  "\u041f\u0440\u043e\u0432\u0456\u0437\u043e\u0440",
  "\u041f\u0440\u043e\u043a\u0443\u0440\u043e\u0440",
  "\u041f\u0440\u043e\u043c\u0438\u0441\u043b\u043e\u0432\u0435\u0446\u044c",
  "\u041f\u0440\u043e\u0444\u0435\u0441\u043e\u0440",
  "\u041f\u0441\u0438\u0445\u043e\u043b\u043e\u0433",
  "\u041f\u0443\u0431\u043b\u0456\u0446\u0438\u0441\u0442",
  "\u041f\u0440\u043e\u0434\u044e\u0441\u0435\u0440",
  "\u041f\u0430\u0431\u043b\u0456\u043a \u0440\u0438\u043b\u0435\u0439\u0448\u043d\u0437",
  "\u0420\u0435\u0436\u0438\u0441\u0435\u0440",
  "\u0420\u0456\u0437\u043d\u043e\u0440\u043e\u0431\u043e\u0447\u0438\u0439",
  "\u0420\u0435\u0430\u0431\u0456\u043b\u0456\u0442\u043e\u043b\u043e\u0433",
  "\u0420\u0435\u0434\u0430\u043a\u0442\u043e\u0440",
  "\u0420\u0435\u0441\u0442\u0430\u0432\u0440\u0430\u0442\u043e\u0440",
  "\u0420\u0456\u0435\u043b\u0442\u043e\u0440",
  "\u0421\u0430\u043d\u0442\u0435\u0445\u043d\u0456\u043a",
  "\u0421\u043a\u043b\u0430\u0434\u0430\u043b\u044c\u043d\u0438\u043a",
  "\u0421\u043a\u0443\u043b\u044c\u043f\u0442\u043e\u0440",
  "\u0421\u043e\u0446\u0456\u043e\u043b\u043e\u0433",
  "\u0421\u043f\u0456\u0432\u0430\u043a",
  "\u0421\u0446\u0435\u043d\u0430\u0440\u0438\u0441\u0442",
  "\u0421\u0442\u0440\u043e\u043f\u0430\u043b\u044c\u043d\u0438\u043a",
  "\u0421\u0442\u043e\u043c\u0430\u0442\u043e\u043b\u043e\u0433",
  "\u0421\u043b\u0456\u0434\u0447\u0438\u0439",
  "\u0421\u0442\u0438\u043b\u0456\u0441\u0442",
  "\u0421\u0435\u043a\u0440\u0435\u0442\u0430\u0440",
  "\u0424\u0430\u0440\u043c\u0430\u0446\u0435\u0432\u0442",
  "\u0424\u0435\u0440\u043c\u0435\u0440",
  "\u0424\u0456\u0437\u0438\u043a",
  "\u0424\u0456\u043b\u043e\u043b\u043e\u0433",
  "\u0424\u043e\u043b\u044c\u043a\u043b\u043e\u0440\u0438\u0441\u0442",
  "\u0424\u043e\u0442\u043e\u0433\u0440\u0430\u0444",
  "\u0424\u0440\u0456\u043b\u0430\u043d\u0441\u0435\u0440",
  "\u0424\u0443\u0442\u0431\u043e\u043b\u0456\u0441\u0442",
  "\u0424\u043b\u043e\u0440\u0438\u0441\u0442",
  "\u0425\u0456\u043c\u0456\u043a",
  "\u0425\u0443\u0434\u043e\u0436\u043d\u0438\u043a",
  "\u0425\u043e\u0440\u0435\u043e\u0433\u0440\u0430\u0444",
  "\u0428\u0435\u0440\u0438\u0444",
  "\u0428\u0432\u0430\u0447\u043a\u0430",
  "\u0428\u0442\u0443\u043a\u0430\u0442\u0443\u0440",
  "\u042e\u0432\u0435\u043b\u0456\u0440",
  "\u042e\u0440\u0438\u0441\u0442"
)

#' Job provider for Ukraine
#'
#' @inherit JobProvider description details return
#' @family uk
#' @family UA
#' @export
#' @examples
#' x <- JobProvider_uk_UA$new()
#' x$render()
JobProvider_uk_UA <- R6::R6Class(
  inherit = JobProvider,
  "JobProvider_uk_UA",
  private = list(
    locale_ = "uk_UA",
    formats = job_formats_uk_ua
  )
)
